==> tpcclib-0.7.8-src.tar.gz: v2/libtpcrand/test_tpcrand.h <==
#ifndef _TEST_TPCRAND_H_
#define _TEST_TPCRAND_H_
/*****************************************************************************/

/*****************************************************************************/
#include "tpcclibConfig.h"
/*****************************************************************************/
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <ctype.h>
#include <math.h>
/*****************************************************************************/
#include "tpcrand.h"
/*****************************************************************************/

/*****************************************************************************/
/* gaussdev */
extern int test_drandSeed(TPCSTATUS *status);
extern int test_drand(TPCSTATUS *status);
extern int test_drandRange(TPCSTATUS *status);
extern int test_drandGaussian(TPCSTATUS *status);
extern int test_drandExponential(TPCSTATUS *status);
/*****************************************************************************/

/*****************************************************************************/
/* shuffle */
extern int test_randomShuffle(TPCSTATUS *status);
extern int test_randomShuffleUnsigned(TPCSTATUS *status);
extern int test_randomPermutation(TPCSTATUS *status);
extern int test_randomPermutationUnsigned(TPCSTATUS *status);
/*****************************************************************************/

/*****************************************************************************/
/* mertwi */
extern int test_mertwiSeed32(TPCSTATUS *status);
extern int test_mertwiSeed64(TPCSTATUS *status);
extern int test_mertwiRandomInt64(TPCSTATUS *status);
extern int test_mertwiRandomDouble1(TPCSTATUS *status);
extern int test_mertwiRandomDouble2(TPCSTATUS *status);
extern int test_mertwiRandomBetween(TPCSTATUS *status);
extern int test_mertwiRandomExponential(TPCSTATUS *status);
extern int test_mertwiRandomGaussian(TPCSTATUS *status);
/*****************************************************************************/

/*****************************************************************************/
#endif /* TEST_TPCRAND */

==> tpcclib-0.8.1-src.tar.gz: v2/libtpcrand/test_tpcrand.h <==
#ifndef _TEST_TPCRAND_H_
#define _TEST_TPCRAND_H_
/*****************************************************************************/

/*****************************************************************************/
#include "tpcclibConfig.h"
/*****************************************************************************/
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <ctype.h>
#include <math.h>
/*****************************************************************************/
#include "tpcrand.h"
/*****************************************************************************/

/*****************************************************************************/
/* gaussdev */
extern int test_drandSeed(TPCSTATUS *status);
extern int test_drand(TPCSTATUS *status);
extern int test_drandRange(TPCSTATUS *status);
extern int test_drandGaussian(TPCSTATUS *status);
extern int test_drandExponential(TPCSTATUS *status);
/*****************************************************************************/

/*****************************************************************************/
/* shuffle */
extern int test_randomShuffle(TPCSTATUS *status);
extern int test_randomShuffleUnsigned(TPCSTATUS *status);
extern int test_randomPermutation(TPCSTATUS *status);
extern int test_randomPermutationUnsigned(TPCSTATUS *status);
/*****************************************************************************/

/*****************************************************************************/
/* mertwi */
extern int test_mertwiSeed32(TPCSTATUS *status);
extern int test_mertwiSeed64(TPCSTATUS *status);
extern int test_mertwiRandomInt64(TPCSTATUS *status);
extern int test_mertwiRandomDouble1(TPCSTATUS *status);
extern int test_mertwiRandomDouble2(TPCSTATUS *status);
extern int test_mertwiRandomBetween(TPCSTATUS *status);
extern int test_mertwiRandomExponential(TPCSTATUS *status);
extern int test_mertwiRandomGaussian(TPCSTATUS *status);
/*****************************************************************************/

/*****************************************************************************/
/* halton */
extern int test_haltonElement(TPCSTATUS *status);
extern int test_haltonPrime(TPCSTATUS *status);
/*****************************************************************************/

/*****************************************************************************/
#endif /* TEST_TPCRAND */
